"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deduplicateMembers = void 0;
/**
 * Deduplicates members by property name, preferring the last occurrence.
 * Used to ensure that overrides replace base properties in the final output.
 *
 * @param members Array of property/type members to deduplicate
 * @returns Deduplicated array with only the last occurrence of each property name
 */
function deduplicateMembers(members) {
    const seen = new Map();
    for (const member of members) {
        if (seen.has(member.name)) {
            const base = seen.get(member.name);
            seen.set(member.name, {
                ...member,
                value: normalizeValue(member.value),
                description: member.description && member.description.trim() !== ''
                    ? member.description
                    : base.description ?? '',
            });
        }
        else {
            seen.set(member.name, {
                ...member,
                value: normalizeValue(member.value),
            });
        }
    }
    return Array.from(seen.values());
}
exports.deduplicateMembers = deduplicateMembers;
function normalizeValue(value) {
    if (typeof value === 'string') {
        // Only normalize if the value is a single string literal or a union of string literals
        // e.g., '"foo"', '"foo" | "bar"', but not '[1, "foo", 2]'
        const stringLiteralOrUnion = /^(["'][^"']*["'])(\s*\|\s*["'][^"']*["'])*$/;
        if (stringLiteralOrUnion.test(value.trim())) {
            return value.replace(/(["'])(.*?)(\1)/g, (match, quote, content) => `'${content}'`);
        }
    }
    return value;
}
