"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseJSDocTags = void 0;
function parseJSDocTags(symbol) {
    const tags = symbol.getJsDocTags();
    let deprecationMessage;
    let isProtected;
    let isPrivate;
    let environmentValue;
    let defaultValue;
    let examples;
    tags.forEach((tag) => {
        if ((tag.name.toLowerCase() === 'default' ||
            tag.name.toLowerCase() === 'defaultvalue') &&
            tag.text) {
            defaultValue = tag.text.map((t) => t.text).join('');
        }
        if (tag.name.toLowerCase() === 'deprecated') {
            deprecationMessage = tag.text
                ? tag.text.map((t) => t.text).join('')
                : 'Deprecated';
        }
        if (tag.name.toLowerCase() === 'protected') {
            isProtected = true;
        }
        if (tag.name.toLowerCase() === 'private') {
            isPrivate = true;
        }
        if ((tag.name.toLowerCase() === 'environment' ||
            tag.name.toLowerCase() === 'environmentvalue') &&
            tag.text) {
            environmentValue = tag.text.map((t) => t.text).join('');
        }
        if (tag.name.toLowerCase() === 'example') {
            if (examples === undefined) {
                examples = [];
            }
            examples.push(parseExampleTag(tag));
        }
    });
    return {
        deprecationMessage,
        isProtected,
        defaultValue,
        isPrivate,
        environmentValue,
        examples,
    };
}
exports.parseJSDocTags = parseJSDocTags;
function parseExampleTag(tag) {
    let TagState;
    (function (TagState) {
        TagState[TagState["Title"] = 0] = "Title";
        TagState[TagState["Description"] = 1] = "Description";
        TagState[TagState["CodeStart"] = 2] = "CodeStart";
        TagState[TagState["TabTitle"] = 3] = "TabTitle";
        TagState[TagState["Code"] = 4] = "Code";
    })(TagState || (TagState = {}));
    const lines = tag.text?.[0].text.split('\n') || [];
    let title = '';
    let description = '';
    const tabs = [];
    let tabCode = '';
    let tabTitle = '';
    // This FSM processes the following format. Captions, tab titles and code fences are optional.
    //
    // <caption>Example title</caption>
    // <description>Example description</description>
    // ```
    // // Tab title 1
    // Tab code
    // ```
    //
    // ```
    // // Tab title 2
    // Tab code
    // ```
    let state = TagState.Title;
    let i = 0;
    while (i < lines.length) {
        const line = lines[i];
        const { content: titleTag, hasTag: hasTitle, closesTag: closesTitle, } = parseExampleXmlTag(line, 'caption');
        const { content: descriptionTag, hasTag: hasDescription, closesTag: closesDescription, } = parseExampleXmlTag(line, 'description');
        let step = true;
        switch (state) {
            case TagState.Title:
                if (hasTitle) {
                    title = titleTag.replace(/\.$/, '');
                }
                else if (closesTitle) {
                    title += titleTag;
                }
                else {
                    step = false;
                }
                // We stay in this state if it's a multi-line tag and it isn't closed
                if (!hasTitle || closesTitle)
                    state = TagState.Description;
                break;
            case TagState.Description:
                if (hasDescription) {
                    description = descriptionTag;
                }
                else if (closesDescription) {
                    description += descriptionTag;
                }
                else {
                    step = false;
                }
                // We stay in this state if it's a multi-line tag and it isn't closed
                if (!hasDescription || closesDescription)
                    state = TagState.CodeStart;
                break;
            case TagState.CodeStart:
                if (line.startsWith('```')) {
                    state = TagState.TabTitle;
                }
                else if (line === '') {
                    // Skip empty lines between code blocks
                }
                else {
                    state = TagState.Code;
                    step = false;
                }
                break;
            case TagState.TabTitle:
                if (line.match(/^\s*\/\//)) {
                    tabTitle = line.replace(/^\s*\/\//, '').trim();
                }
                else {
                    step = false;
                }
                state = TagState.Code;
                break;
            case TagState.Code:
                if (line.startsWith('```')) {
                    tabs.push({
                        code: tabCode.trim(),
                        title: tabTitle === '' ? 'Example' : tabTitle,
                    });
                    tabCode = '';
                    state = TagState.CodeStart;
                }
                else {
                    tabCode += `${line}\n`;
                    state = TagState.Code;
                }
                break;
        }
        if (step)
            i++;
    }
    const example = {
        title: title === '' ? 'Example' : title,
        description: description ?? '',
        tabs,
    };
    if (tabCode !== '') {
        example.tabs.push({
            code: tabCode.trim(),
            title: tabTitle === '' ? 'Example' : tabTitle,
        });
    }
    return example;
}
function parseExampleXmlTag(line, tag) {
    let hasTag = false;
    let closesTag = false;
    let content = line;
    if (line.includes(`<${tag}>`)) {
        hasTag = true;
        content = content.replace(`<${tag}>`, '').trim();
    }
    if (line.includes(`</${tag}>`)) {
        closesTag = true;
        content = content.replace(`</${tag}>`, '').trim();
    }
    return {
        content,
        hasTag,
        closesTag,
    };
}
