interface compareDocs {
    /** Specifies the folder where the generated files are located.
     *
     * @default `./docs/generated/` */
    output?: string;
    /** Help message with description of command and available options.
     *
     * Alternatively, you can use the `--h` flag to display this message.
     */
    help?: '';
}

interface ConfigOptions {
    /** The name of your reference. Will determine the url at which your reference appears in the form of `/api/{name}/`. */
    name: string;
    /** Flag that will gate your reference from being seen until you are ready. If you delete the `beta_flag` entry, your documentation will go live. */
    beta_flag: string;
    /** Github team used for tagging in feedback issues. */
    github_teams: string;
    /** Link to your team's vault page. */
    vault_team_url: string;
    /** The order you want your categories to appear in the sidebar. The array of strings can contain the name of the category in lowercase with dashes between words or can be the id of the landing page. */
    sidebar_order: string[];
    /** The category names of any category overview page you wish to hide. */
    disabledCategories?: string[];
    /** Configuration to automatically update your repo's documentation. */
    github_automation?: ConfigGithubOptions;
    /** The versioning scheme you want to use. Leave empty if you are not versioning your reference */
    version_scheme?: 'semver' | 'calver';
    /** Image used as the default image for all category previews. The string given will be the path to the image in shopify.dev. */
    category_image?: string;
    /** Dark mode image used as the default image for all category previews. The string given will be the path to the image in shopify.dev. */
    category_image_dark?: string;
    /**  Hides the type information for reference entities in definition lists. Used for references that don't have types beyond string. */
    hide_types?: boolean;
    /** Use if your versioning matches that of Shopify's GQL versioning. You have an unstable, release candidate, and latest version as your first three versions. This effects the annotations in the version selector drop down. */
    usesStandardVersioning?: boolean;
}
interface ConfigGithubOptions {
    /** Set value to true if your team wants their files automatically synced. */
    enabled: boolean;
    /** The name of the repository (e.g., shopify/hydrogen-UI). */
    repo: string;
    /** The branches (e.g., 'main', 'master', '2022-07-v1', etc.) from which documentation files will be pulled. */
    branches: string[];
    /** Where in the repository `generated_docs_data.json` and `generated_static_pages.json` live. */
    generated_files_path: string;
    /** Where the screenshots in the repository live. */
    screenshots_path: string;
    /** The path to the package manager file (e.g., package.json). If `package_manager_version_regex` isn't set, behaviour will be assumed based on the file name. */
    package_manager_path: string;
    /** The regex used to extract the version from the package manager file. If omitted, behaviour will be assumed from the file name. */
    package_manager_version_regex?: string;
}

interface generateDocs {
    /** Specifies the input directory of files to parse. Can provide multiple paths separated by a space.
     *
     * Defaults to the current working directory.
     */
    input?: string;
    /** Specifies where the output will be generated.
     *
     * @default current working directory
     */
    output?: string;
    /** Processes landing pages without running type generator.
     *
     * @default false
     */
    isLandingPage?: boolean;
    /** Specifies a path to override the default path. */
    overridePath?: string;
    /**
     * Specifies one or more space-separated paths from which declaration (`.d.ts`) files may be included when extracting types.
     *
     * Paths within `node_modules` are allowed, but packages should be included individually to minimize the impact on performance.
     */
    declarationPath?: string;
    /** Additional set of paths that may be used to document TypeScript types that exist outside of the path(s) specified to `input`.  Can provide a single path or multiple paths separated by a space. */
    typesInput?: string;
    /** Help message with description of command and available options.
     *
     * Alternatively, you can use the `--h` flag to display this message.
     */
    help?: '';
}

interface scaffoldDocs {
    /** The type of template to generate, options are limited to "entity" or "static".
     *
     * @default "entity"
     */
    type?: 'static' | 'entity';
    /** Specifies where the file output will be generated.
     *
     * @default current working directory
     */
    output?: string;
    /** The name of the file. */
    name: string;
    /** The ID of the static page. Note: Reference entity pages do not have an ID. */
    id: string;
    /** Help message with description of command and available options.
     *
     * Alternatively, you can use the `--h` flag to display this message.
     */
    help?: '';
}

interface setUpConfig {
    /** The name of your reference including caps and dashes between words. This will become part of the url path for your reference.  */
    name: string;
    /** Help message with description of command and available options.
     *
     * Alternatively, you can use the `--h` flag to display this message.
     */
    help?: '';
}

interface setUpDocs {
    /** The path to the folder containing the source files. Can provide multiple paths separated by a space.
     *
     * @default `./src`
     */
    srcInput?: string;
    /** Additional set of paths that may be used to document TypeScript types that exist outside of the path(s) specified to `srcInput`.  Can provide a single path or multiple paths separated by a space. */
    typesInput?: string;
    /** Help message with description of command and available options.
     *
     * Alternatively, you can use the `--h` flag to display this message.
     */
    help?: '';
}

interface CodeLinkType {
    /** Text to display in the tooltip. */
    name: string;
    /** Link url. */
    url: string;
    /** Icon to display. */
    icon: string;
}
interface CodeTabType {
    /** The title of the tab. */
    title?: string;
    /** The relative link to the code file. */
    code: string;
    /** The language of the code file. */
    language?: string;
}
interface CodeblockType {
    /** The data for each tab in the code block. */
    tabs: CodeTabType[];
    /** The title of the codeblock. */
    title: string;
    /** Links to display in the top right corner of the code block. */
    links?: CodeLinkType[];
}
type StackedCodeblockType = CodeblockType[];
interface RawExampleTab {
    code: string;
    title?: string;
}
interface RawExample {
    title: string;
    description: string;
    tabs: RawExampleTab[];
}
interface MemberType {
    /** The name of the member. */
    name: string;
    /** A description of the member. Can include Markdown. */
    description: string;
    /** A value to be displayed in the member. */
    value: string | number;
    /** The default value of the member, if any. */
    defaultValue?: string;
    /** Boolean that determines if the member is optional. */
    isOptional?: boolean;
    /** Boolean that determines if the member is protected. */
    isProtected?: boolean;
    /** Boolean that determines if the member is private. */
    isPrivate?: boolean;
    /** The environment value of the member, if any. */
    environmentValue?: string;
    /** A message stating this member is deprecated. */
    deprecationMessage?: string;
    /** A type used to pull the description from the code comments. */
    examples?: RawExample[];
}

interface ExampleType {
    /** Description of the example. Can use Markdown.  */
    description?: string;
    /** The data for the code block. */
    codeblock: CodeblockType | StackedCodeblockType;
    /** If used will cause the example group to only be visible when the feature flag is enabled. */
    featureFlag?: string;
    /** An image preview of the example. Provide just the name of the image, such as `fakeImageName.png`.
     *
     * If no thumbnail is provided, the defaultExample's image will be used in the category grid, if available. */
    image?: string;
    /** The alt text for the image. */
    altText?: string;
}
interface ExampleGroupType {
    /** A section for the grouped examples. */
    examples: ExampleType[];
    /** Title of the example group. */
    title?: string;
    /** If used will cause the example group to only be visible when the feature flag is enabled. */
    featureFlag?: string;
}
interface ExampleSectionSchema {
    /** Description of the example section. Can use Markdown. */
    description: string;
    /** May be used to group examples of a certain theme. These examples will be grouped under a given title. */
    exampleGroups?: ExampleGroupType[] | null;
    /** May be used to group examples without a particular theme. */
    examples?: ExampleType[] | null;
}

interface LinkType {
    /** The name of the link. */
    name: string;
    /** A subordinate title providing additional information. The subtitle should be limited to a one word description when in the related section. */
    subtitle?: string;
    /** The link to the entity. */
    url: string;
    /** What category the entity is (e.g., component, hook, utility, etc.). Determines the icon on the card. */
    type?: string | null;
    /** If used will cause the card to only be visible when the feature flag is enabled. */
    featureFlag?: string;
}
interface RelatedSectionSchema {
    /** A section that displays related entities in a grid of cards. */
    related: LinkType[];
}

declare const SectionType: {
    readonly Generic: "Generic";
    readonly GenericAccordion: "GenericAccordion";
    readonly GenericList: "GenericList";
    readonly Resource: "Resource";
    readonly Markdown: "Markdown";
    readonly WebhooksAccordion: "WebhooksAccordion";
};
type SectionTypes = (typeof SectionType)[keyof typeof SectionType];
interface Section {
    type: SectionTypes;
}

interface SectionNoticeType {
    /** The title of the notice. */
    title: string;
    /** The content of the notice. */
    sectionContent: string;
    /** The type of notice. Options include:
     *
     * - `info` (default) - A blue notice.
     *
     * - `warning` - A yellow notice.
     *
     * - `critical` - A red notice.
     *
     * - `note` - A gray notice.
     */
    type: string | 'info';
}
interface SectionContentType {
    /** The title of the subsection. */
    title: string;
    /** Content that appears in the subsection. */
    sectionContent: string;
    /** A way to author notices at the end of the subsection content. */
    sectionNotice?: SectionNoticeType[];
    /** A way to author cards at the end of the subsection content. */
    sectionCard?: LinkType[];
}
/** The generic section is the most flexible content section for landing pages and can be used for everything except the first and last sections.
 * @type id for the generic section (i.e., "Generic"). */
interface GenericSectionSchema extends Section {
    /** ID for the generic section (i.e., "Generic"). */
    type: typeof SectionType.Generic;
    /** Anchor link for the section. */
    anchorLink: string;
    /** The title of the section. */
    title: string;
    /** Content for the section. */
    sectionContent: string;
    /** A way to author notices at the end of the section content. */
    sectionNotice?: SectionNoticeType[];
    /** A way to author cards at the end of the section content. */
    sectionCard?: LinkType[];
    /** A way to author subsections inside the section that are separated from the main content by a horizontal line. */
    sectionSubContent?: SectionContentType[];
    /** Code block with multiple tabs that contain samples for each language/framework. */
    codeblock?: CodeblockType | StackedCodeblockType;
    /** An image to be displayed on the left hand side of the page. Provide just the name of the image, such as `fakeImageName.png`. */
    image?: string;
    /** The alt text for the image. */
    altText?: string;
    /** The default selected language. If none is provided, the language will default to the first language in the `codeLanguages` array. */
    initialLanguage?: string;
}

interface TypeDefinition {
    /** The name of the type. */
    name: string;
    /** A description of the type. Can include Markdown. */
    description: string;
    /** Members of the type. */
    members?: MemberType[];
    /** Type definitions parameters. */
    params?: MemberType[];
    /** Type definitions return values. */
    returns?: MemberType;
    /** A value of the type definitions type. */
    value: string;
    /** An optional type override. */
    override?: string;
    /** Examples of the type. */
    examples?: TypeExample[];
}
interface TypeExampleTab {
    /** The title of the tab. */
    title: string;
    /** The code of the tab. */
    code: string;
}
interface TypeExample {
    /** A description of the example. */
    description: string;
    /** The tabs for the example's codeblock. */
    tabs: TypeExampleTab[];
}
interface TypeDefinitionsType {
    [typeName: string]: TypeDefinition;
}
interface DefinitionsType {
    /** Title of the list of definitions. */
    title: string;
    /** Description of the definitions. Can use Markdown. */
    description: string;
    /** Name of the TypeScript type this entity uses. */
    type: string;
    /** The file path for the type this entity uses. The filePath is relative to current working directory as defined by `process.cwd()`. */
    filePath?: string;
    /** Type definitions.  */
    typeDefinitions?: TypeDefinitionsType;
}
interface IntroSectionSchema {
    /** The name of the page. */
    name: string;
    /** A description of the reference entity. Can include Markdown. */
    description: string;
    /** A type used to pull the description from the code comments. If you want to use a function use FunctionNameGeneratedType. This will override the description field if used. */
    descriptionType?: string;
    /** A short sentence of what is needed to use this entity, such as a version dependency. */
    requires?: string;
    /** What category the entity is (e.g., component, hook, utility, section, etc.). */
    type?: string;
    /** The example that appears in the right hand column at the top of the page. Represents the primary use case. */
    defaultExample?: ExampleType | null;
    /** Boolean that determines if the entity is a visual component. */
    isVisualComponent: boolean;
    /**
     * Change from the default two column layout to one column layout, allowing children, such as examples, to expand full width.
      @default false (two column layout)
    */
    isOneColumnLayout?: boolean;
    /** Displays generated TypeScript information, such as prop tables. */
    definitions?: DefinitionsType[];
    /** A way to author subsections inside the section that are separated from the main content by a horizontal line. */
    subSections?: GenericSectionSchema[];
}
interface SplitTokensType {
    /** An array of the tokens that are an exact match to a typeDefinition. */
    expandableTokens: string[];
    /** An array of tokens from a string that has been split up by special characters and blank spaces. */
    tokens: string[];
}

interface ReferenceEntityTemplateSchema extends IntroSectionSchema, RelatedSectionSchema {
    /** The title of the page. */
    name: string;
    /** If used will cause the page to only be visible when the feature flag is enabled. */
    featureFlag?: string;
    /** The category of the page. */
    category: string;
    /** The subcategory of the page. */
    subCategory?: string;
    /** The description of the page that will appear on the overview page. If none is provided, will default to the category's description. */
    overviewPreviewDescription?: string;
    /** A thumbnail image to display in the category page. Provide just the name of the image, such as `fakeImageName.png`. If none provided, will use the defaultExample image, if available. */
    thumbnail?: string;
    /** A section for examples. Examples may be grouped (i.e., exampleGroups) or ungrouped (i.e., examples). */
    examples?: ExampleSectionSchema;
    /** Examples pulled from a list of types to be included. */
    jsDocTypeExamples?: string[];
}

interface CategorySectionSchema {
    /** The reference entity data/content. */
    data: ReferenceEntityTemplateSchema[];
    /** The reference name (e.g., hydrogen, liquid, graphql, etc.). */
    reference: string;
}

interface GenericAccordionSection extends Section {
    /** ID for the generic accordion section (i.e., "GenericAccordion"). */
    type: typeof SectionType.GenericAccordion;
    /** The anchor link for the section. */
    anchorLink: string;
    /** The content of the section. */
    sectionContent?: string;
    /** The title of the section. */
    title: string;
    /** The content of the accordion. */
    accordionContent: GenericAccordionType[];
}
interface GenericAccordionType {
    /** Title of the accordion. */
    title: string;
    /** Description of the accordion. */
    description: string;
    /** A code block with multiple tabs that contain samples for each language/framework.  */
    codeblock?: CodeblockType | StackedCodeblockType;
    /** The default selected language. If none provided, will default to the first language in the `codeLanguages` array. */
    initialLanguage?: string;
    /** An image preview to be displayed under the code block, if also provided. Provide just the name of the image, such as `fakeImageName.png`. */
    image?: string;
    /** The alt text for the image. */
    altText?: string;
    /** A way to author cards at the end of the accordion content. */
    sectionCard?: LinkType[];
}

interface ListSectionContentType {
    /** The title of the subsection. */
    title: string;
    /** Content that appears in the subsection. */
    sectionContent: string;
    /** Items that will appear in the list. */
    listItems?: MemberType[];
}
interface GenericListSection extends Section {
    /** ID for the generic accordion section (i.e., "GenericList"). */
    type: typeof SectionType.GenericList;
    /** The anchor link for the section. */
    anchorLink: string;
    /** The content of the section. */
    sectionContent?: string;
    /** The title of the section. */
    title: string;
    /** Items that will appear in the list. */
    listItems: MemberType[];
    /** Code block with multiple tabs that contain samples for each language/framework. */
    codeblock?: CodeblockType | StackedCodeblockType;
    /** An image to be displayed on the left hand side of the page. Provide just the name of the image, such as `fakeImageName.png`. */
    image?: string;
    /** The alt text for the image. */
    altText?: string;
    /** Styles the section for use as a subsection when true. */
    isSubSection?: boolean;
    /** Adds additional list subsections.*/
    subSectionContent?: ListSectionContentType[];
}

interface HeroSectionSchema {
    /** The title of the hero section. */
    title: string;
    /** The description of the hero section. */
    description: string;
    /** The image to display in the hero section. Always provide the path to the image, such as `path/to/image/fakeImageName.png`. */
    image?: string;
}

/** The resource section contains cards with links to other resources listed in a grid.
 *
 * - `type` - ID for the resources section (i.e., "Resource"). */
interface ResourcesSectionSchema extends Section {
    /** ID for the resource section (i.e., "Resource"). */
    type: typeof SectionType.Resource;
    /** Anchor link for the section. */
    anchorLink: string;
    /** The title of the section. */
    title: string;
    /** Content for each card in the section. */
    resources: LinkType[];
    /** If used will cause the page to only be visible when the feature flag is enabled. */
    featureFlag?: string;
}

interface ScreenshotType {
    /** Image to be displayed in the Screenshot. */
    image: string | undefined;
    /** The styling of the Screenshot. */
    className?: string;
    /** The alt text for the image. */
    altText?: string;
}

interface MarkdownSection extends Section {
    /** ID for the Markdown section (i.e., "Markdown"). */
    type: typeof SectionType.Markdown;
    /** Anchor link for the section. */
    anchorLink: string;
    /** The title of the section. */
    title: string;
    /** Content for the section. */
    sectionContent: string;
    /** A way to author subsections inside the section that are separated from the main content by a horizontal line. */
    sectionSubContent?: SectionContentType[];
    /** A way to author notices at the end of the section content. */
    sectionNotice?: SectionNoticeType[];
    /** A way to author cards at the end of the section content. */
    sectionCard?: LinkType[];
}

interface WebhooksAccordionSection extends Omit<GenericAccordionSection, 'type' | 'accordionContent'> {
    /** ID for the tabbed accordion section (i.e., "WebhooksAccordion"). */
    type: typeof SectionType.WebhooksAccordion;
    /** Tabs displayed at the top of the accordion. */
    tabs: string[];
    /** Content for the accordion. */
    accordionContent: WebhooksAccordionType[];
}
interface WebhooksAccordionType extends GenericAccordionType {
    /** Determines which reference(s) the topic name is available on. All values must be included in the `WebhooksAccordionSection`'s `tabs`. */
    availableOn: string[];
    /** Webhooks personal identifiable information (pii). If the array contains `customer`, a pii bage will be added next to the title (i.e., topic name). */
    pii?: string[];
    /** Webhooks related resource name. */
    relatedResource?: string;
    /** Webhooks `access_scopes` names. */
    accessScopes?: string[];
    /** Webhooks warning notices. */
    webhooksNotices?: WebhooksNoticeType[];
}
/** The type of webhooks warning, such as 'deprecated', 'compliance', or 'scope'.
 *
 * If type is 'scope', provide the `scopes` or `approvalScopes` properties.
 */
type WebhooksNoticeType = NoticeType | ScopeNoticeType;
interface NoticeType {
    /** Webhooks warning type. */
    type: 'deprecated' | 'compliance' | 'shopFeature';
}
interface ScopeNoticeType {
    /** Webhooks scope notice. */
    type: 'scope';
    /** The webhooks warning approval scopes. */
    approvalScopes: string[];
}

interface LandingTemplateSchema {
    /** The title of the page. */
    title: string;
    /** A short description of the page. Appears in the hero section below the title. */
    description: string;
    /** If used will cause the page to only be visible when the feature flag is enabled. */
    featureFlag?: string;
    /** The image used in the hero section. Always provide the path to the image, such as `path/to/image/fakeImageName.png`.
     *
     * To use a default image, set the value to `/assets/landing-pages/templated-apis/hero.png`.
     */
    image?: string;
    /** The image used in the hero section. Always provide the path to the image, such as `path/to/image/fakeImageName.png`.
     *
     * To use a default image, set the value to `/assets/landing-pages/templated-apis/hero-dark.png`.
     */
    darkImage?: string;
    /** The image used in the hero section. Always provide the path to the image, such as `path/to/image/fakeImageName.png`. */
    tabletImage?: string;
    /** The image used in the hero section in dark mode. Always provide the path to the image, such as `path/to/image/fakeImageName.png`. */
    tabletDarkImage?: string;
    /** The image used in the hero section. Always provide the path to the image, such as `path/to/image/fakeImageName.png`. */
    mobileImage?: string;
    /** The image used in the hero section in dark mode. Always provide the path to the image, such as `path/to/image/fakeImageName.png`. */
    mobileDarkImage?: string;
    /** The ID for the page that is used for routing. If this documentation is for a primary landing page, confirm ID matches the reference name. */
    id: string;
    /** Basic content for the page and hero sections. Options include:
     *
     * - `GenericAccordionSection` - A more flexible section. Can be used multiple times. Creates an accordion type dropdown.
     *
     * - `GenericSectionSchema` - A more flexible section. Can be used multiple times.
     *
     * - `GenericListSection` - A more flexible section that can contain manually created definition lists. Can be used multiple times.
     *
     * - `ResourcesSectionSchema` - A section that contains cards with links to other resources listed in a grid.
     */
    sections: [
        (GenericSectionSchema | MarkdownSection | GenericAccordionSection | GenericListSection),
        ...(GenericSectionSchema | MarkdownSection | GenericAccordionSection | GenericListSection)[],
        (ResourcesSectionSchema | GenericSectionSchema | MarkdownSection | GenericListSection | GenericAccordionSection)
    ];
}

interface EntityTags {
    /** Displays the default value of a prop. */
    default?: any;
    /** Displays the default value of a prop. */
    defaultValue?: any;
    /** Marks the prop as deprecated. Can provide a message after the tag regarding the deprecation. */
    deprecated?: string;
    /** Displays the environment variable. */
    environment?: string;
    /** Displays an example of how to use the prop.
     *
     * Caution: Use of this tag requires adding `jsDocTypeExamples: string[],` to the reference entity file. See a more detailed example below.
     */
    example?: string;
    /** Hides the prop from the documentation. */
    private?: '';
    /** Marks the prop as protected by styling the prop with a protected tooltip. */
    protected?: '';
}

interface CategoryTemplateSchema {
    /** The name of the category used to document reference entities. */
    category: string;
    /** The title of the category page. If not used the title will be the category name. */
    title?: string;
    /** Basic content for the page and hero sections. Options include:
     *
     * - `GenericSectionSchema` - A more flexible section. Can be used multiple times.
     *
     */
    sections: [...GenericSectionSchema[]];
}

export { CategorySectionSchema, CategoryTemplateSchema, CodeTabType, CodeblockType, ConfigGithubOptions, ConfigOptions, DefinitionsType, EntityTags, ExampleGroupType, ExampleSectionSchema, ExampleType, GenericAccordionSection, GenericAccordionType, GenericListSection, GenericSectionSchema, HeroSectionSchema, IntroSectionSchema, LandingTemplateSchema, LinkType, MarkdownSection, MemberType, NoticeType, ReferenceEntityTemplateSchema, RelatedSectionSchema, ResourcesSectionSchema, ScopeNoticeType, ScreenshotType, Section, SectionContentType, SectionNoticeType, SectionTypes, SplitTokensType, StackedCodeblockType, TypeDefinitionsType, TypeExample, WebhooksAccordionSection, WebhooksAccordionType, WebhooksNoticeType, compareDocs, generateDocs, scaffoldDocs, setUpConfig, setUpDocs };
